==> parsercher-3.1.4.crate: parsercher-3.1.4/CHANGELOG.md <==
# Changelog

## [3.1.4] - 2021-08-26

### Fixes

- Fixed parsing of tag terminal symbol `>`.


## [3.1.3] - 2021-06-07

### Fixes

- Fixed to trim the tag name.


## [3.1.2] - 2021-05-26

### Changes

- Added support for parsing tag attributes enclosed in single quotes.


## [3.1.1] - 2021-05-18

### Fixes
- Fixed a bug where `Input.set_cursor ()` could move the cursor after EOF.


## [3.1.0] - 2021-05-16

### Additions

- Added new API `parsercher::search_attrs()`.


## [3.0.0] - 2021-05-16

### Additions

- Added new API `parsercher::search_attr()`.
- Added PartialEq to Dom Types.

### Changes

- Changed the `satisfy_sufficient_condition()` to the `Dom::p_implies_q()`.
- Changed constructor arguments to slices (Tag, Text, Comment).


## [2.1.0] - 2021-05-14

### Additions

- Added new API `parsercher::search_dom()`
- Added new API `Dom::p_implies_q()`
- Added new API `Dom::p_implies_q_tree()`


## [2.0.0] - 2021-05-09

### Additions

- Various tests.

### Changes

- Changed the `Tag::set_attr()` to the `Tag::set_attrs()`.
- Changed the `Tag::get_attr()` to the `Tag::get_attrs()`.
- Updated the `Tag::set_attr()` and the `Tag::get_attr()`.
- Moved the `satisfy_sufficient_condition()` to the `tag` mod from the `searcher` mod.


## [1.0.0] - 2021-05-08
Initial release.

[3.1.4]: https://github.com/kkmtyyz/parsercher/compare/v3.1.3...v3.1.4
[3.1.3]: https://github.com/kkmtyyz/parsercher/compare/v3.1.2...v3.1.3
[3.1.2]: https://github.com/kkmtyyz/parsercher/compare/v3.1.1...v3.1.2
[3.1.1]: https://github.com/kkmtyyz/parsercher/compare/v3.1.0...v3.1.1
[3.1.0]: https://github.com/kkmtyyz/parsercher/compare/v3.0.0...v3.1.0
[3.0.0]: https://github.com/kkmtyyz/parsercher/compare/v2.1.0...v3.0.0
[2.1.0]: https://github.com/kkmtyyz/parsercher/compare/v2.0.0...v2.1.0
[2.0.0]: https://github.com/kkmtyyz/parsercher/compare/v1.0.0...v2.0.0
[1.0.0]: https://github.com/kkmtyyz/parsercher/compare/v1.0.0

==> parsercher-3.1.5.crate: parsercher-3.1.5/CHANGELOG.md <==
# Changelog

## [3.1.5] - 2021-10-18

### Changes

- Added support for parsing tag attributes enclosed in space(` `).


## [3.1.4] - 2021-08-26

### Fixes

- Fixed parsing of tag terminal symbol `>`.


## [3.1.3] - 2021-06-07

### Fixes

- Fixed to trim the tag name.


## [3.1.2] - 2021-05-26

### Changes

- Added support for parsing tag attributes enclosed in single quotes.


## [3.1.1] - 2021-05-18

### Fixes
- Fixed a bug where `Input.set_cursor ()` could move the cursor after EOF.


## [3.1.0] - 2021-05-16

### Additions

- Added new API `parsercher::search_attrs()`.


## [3.0.0] - 2021-05-16

### Additions

- Added new API `parsercher::search_attr()`.
- Added PartialEq to Dom Types.

### Changes

- Changed the `satisfy_sufficient_condition()` to the `Dom::p_implies_q()`.
- Changed constructor arguments to slices (Tag, Text, Comment).


## [2.1.0] - 2021-05-14

### Additions

- Added new API `parsercher::search_dom()`
- Added new API `Dom::p_implies_q()`
- Added new API `Dom::p_implies_q_tree()`


## [2.0.0] - 2021-05-09

### Additions

- Various tests.

### Changes

- Changed the `Tag::set_attr()` to the `Tag::set_attrs()`.
- Changed the `Tag::get_attr()` to the `Tag::get_attrs()`.
- Updated the `Tag::set_attr()` and the `Tag::get_attr()`.
- Moved the `satisfy_sufficient_condition()` to the `tag` mod from the `searcher` mod.


## [1.0.0] - 2021-05-08
Initial release.

[3.1.5]: https://github.com/kkmtyyz/parsercher/compare/v3.1.4...v3.1.5
[3.1.4]: https://github.com/kkmtyyz/parsercher/compare/v3.1.3...v3.1.4
[3.1.3]: https://github.com/kkmtyyz/parsercher/compare/v3.1.2...v3.1.3
[3.1.2]: https://github.com/kkmtyyz/parsercher/compare/v3.1.1...v3.1.2
[3.1.1]: https://github.com/kkmtyyz/parsercher/compare/v3.1.0...v3.1.1
[3.1.0]: https://github.com/kkmtyyz/parsercher/compare/v3.0.0...v3.1.0
[3.0.0]: https://github.com/kkmtyyz/parsercher/compare/v2.1.0...v3.0.0
[2.1.0]: https://github.com/kkmtyyz/parsercher/compare/v2.0.0...v2.1.0
[2.0.0]: https://github.com/kkmtyyz/parsercher/compare/v1.0.0...v2.0.0
[1.0.0]: https://github.com/kkmtyyz/parsercher/compare/v1.0.0
